import datetime

def build_date():
    now = datetime.date.today()
    m = now.strftime('%B')
    y = now.strftime('%Y')
    if now.day == 11:
        s = 'th'
    elif now.day % 10 == 1:
        s = 'st'
    elif now.day == 12:
        s = 'th'
    elif now.day % 10 == 2:
        s = 'nd'
    elif now.day == 13:
        s = 'th'
    elif now.day == 3:
        s = 'rd'
    else:
        s = 'th'
    d = '%2d%s' % (now.day, s)
    return '%s %s %s' % (d, m, y)

extensions = [
	"sphinx.ext.autodoc",
	"sphinx.ext.coverage",
	"sphinx.ext.doctest",
	"sphinx.ext.graphviz",
	"sphinx.ext.intersphinx",
	"sphinx.ext.mathjax",
	"sphinxcontrib.bibtex",
	"rtemsext",
	"rtemsdomain",
]

# Add any paths that contain templates here, relative to this directory.
#templates_path = ['build/_templates']

# The suffix of source filenames.
source_suffix = '.rst'

# The encoding of source files.
#source_encoding = 'utf-8-sig'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = u'RTEMS Documentation Project'
copyright = u'2018, RTEMS Project (built %s)' % (build_date())

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
#version = '@VERSION@'

# The full version, including alpha/beta/rc tags.
#release = '@RELEASE@'

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#language = None

# There are two options for replacing |today|: either, you set today to some
# non-false value, then it is used:
#today = ''
# Else, today_fmt is used as the format for a strftime call.
#today_fmt = '%B %d, %Y'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
exclude_patterns = []

# The reST default role (used for this markup: `text`) to use for all documents.
#default_role = None

# If true, '()' will be appended to :func: etc. cross-reference text.
#add_function_parentheses = True

# If true, the current module name will be prepended to all description
# unit titles (such as .. function::).
#add_module_names = True

# If true, sectionauthor and moduleauthor directives will be shown in the
# output. They are ignored by default.
#show_authors = False

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# A list of ignored prefixes for module index sorting.
#modindex_common_prefix = []

# -- Options for HTML output ---------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.

import sphinx_rtd_theme_rtems
html_theme = "sphinx_rtd_theme_rtems"
html_theme_path = [sphinx_rtd_theme_rtems.get_html_theme_path()]

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
html_theme_options = {
    'collapse_navigation': False,
    'display_version': True,
    'sticky_navigation': True,
    'genindex': True,
}

# Add any paths that contain custom themes here, relative to this directory.
#html_theme_path = []

# The name for this set of Sphinx documents.  If None, it defaults to
# "<project> v<release> documentation".
#html_title = None

# A shorter title for the navigation bar.  Default is the same as html_title.
#html_short_title = None

# The name of an image file (relative to this directory) to place at the top
# of the sidebar.
#html_logo = None

# The name of an image file (within the static path) to use as favicon of the
# docs.  This file should be a Windows icon file (.ico) being 16x16 or 32x32
# pixels large.
#html_favicon = None

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['build/_static']

# If not '', a 'Last updated on:' timestamp is inserted at every page bottom,
# using the given strftime format.
#html_last_updated_fmt = '%b %d, %Y'

# If true, SmartyPants will be used to convert quotes and dashes to
# typographically correct entities.
#html_use_smartypants = True

# Custom sidebar templates, maps document names to template names.
#html_sidebars = {}

html_sidebars = {
#	'index':    ['sidebarlogo.html', 'sidebarintro.html', 'sourcelink.html','searchbox.html'],
#	'**':       ['sidebarlogo.html', 'localtoc.html', 'relations.html', 'sourcelink.html', 'searchbox.html']
}


# Additional templates that should be rendered to pages, maps page names to
# template names.
#html_additional_pages = {}

# If false, no module index is generated.
#html_domain_indices = True

# If false, no index is generated.
#html_use_index = True

# If true, the index is split into individual pages for each letter.
#html_split_index = False

# If true, links to the reST sources are added to the pages.
html_show_sourcelink = False

# If true, "Created using Sphinx" is shown in the HTML footer. Default is True.
#html_show_sphinx = True

# If true, "(C) Copyright ..." is shown in the HTML footer. Default is True.
#html_show_copyright = True

# If true, an OpenSearch description file will be output, and all pages will
# contain a <link> tag referring to it.  The value of this option must be the
# base URL from which the finished HTML is served.
#html_use_opensearch = ''

# This is the file name suffix for HTML files (e.g. ".xhtml").
#html_file_suffix = None

# Output file base name for HTML help builder.
htmlhelp_basename = 'rtemsdoc'


# -- Options for LaTeX output --------------------------------------------------
latex_paper_size = 'a4'

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title, author, documentclass [howto/manual]).
latex_documents = [] # must be overridden in local conf.py

# Additional stuff for LaTeX
#    'fontpkg':      r'\usepackage{mathpazo}',
latex_elements = {
    'papersize':    'a4paper',
    'pointsize':    '11pt',
    'preamble':     r'''
\newcommand{\rtemscopyright}{%s}
\usepackage{rtemsstyle}
''' % (copyright),
    'parsedliteralwraps': True,
}


latex_additional_files = ['../common/rtemsstyle.sty', '../common/minted.sty', '../common/logo.pdf']
latex_use_modindex = False


# The name of an image file (relative to this directory) to place at the top of
# the title page.
#latex_logo = None

# If true, show page references after internal links.
latex_show_pagerefs = False

# If true, show URL addresses after external links.
#latex_show_urls=True

# Documents to append as an appendix to all manuals.
#latex_appendices = []

# If false, no module index is generated.
#latex_domain_indices = True


# Example configuration for intersphinx: refer to the Python standard library.
#intersphinx_mapping = {'http://docs.python.org/': None}

highlight_language = "c"
